@@ -9,7 +9,19 @@ from pyflowline.classes.basin import pybasin
 
 
 
-def pyflowline_generate_basin_template_configuration_json_file(sFilename_basins_json, nBasin, sWorkspace_output, sPath_data_input):
+def pyflowline_generate_basin_template_configuration_json_file(sFilename_basins_json, nBasin, sWorkspace_input_in, sWorkspace_output_in):
+    """generate baisn configureation
+
+    Args:
+        sFilename_basins_json (str): the filename
+        nBasin (int): the total number of basin
+        sWorkspace_input_in (str): the input data path
+        sWorkspace_output (str): the output path
+
+    Returns:
+        basin: a basin object
+    """
+
     aBasin_out = list()
     for i in range(nBasin):
         sBasin =  "{:03d}".format(i+1)   
@@ -22,15 +34,15 @@ def pyflowline_generate_basin_template_configuration_json_file(sFilename_basins_
         aConfig_basin['dAccumulation_threshold'] = -90
         aConfig_basin['dThreshold_small_river'] = 90
         
-        aConfig_basin['sFilename_dam'] = str(Path(sPath_data_input)  /  'ICoM_dams.csv')
+        aConfig_basin['sFilename_dam'] = str(Path(sWorkspace_input_in)  /  'ICoM_dams.csv')
         
-        aConfig_basin['sFilename_flowline_filter'] = str(Path(sPath_data_input)  /  'streamord7above.shp')
+        aConfig_basin['sFilename_flowline_filter'] = str(Path(sWorkspace_input_in)  /  'streamord7above.shp')
         
-        aConfig_basin['sFilename_flowline_raw'] = str(Path(sPath_data_input)  /  'allflowline.shp')
+        aConfig_basin['sFilename_flowline_raw'] = str(Path(sWorkspace_input_in)  /  'allflowline.shp')
         
-        aConfig_basin['sFilename_flowline_topo'] = str(Path(sPath_data_input)  /  'flowline.csv')
+        aConfig_basin['sFilename_flowline_topo'] = str(Path(sWorkspace_input_in)  /  'flowline.csv')
         
-        aConfig_basin['sWorkspace_output_basin'] = str(Path(sWorkspace_output) / sBasin )
+        aConfig_basin['sWorkspace_output_basin'] = str(Path(sWorkspace_output_in) / sBasin )
         pBasin = pybasin(aConfig_basin)    
         aBasin_out.append(pBasin)
         
@@ -45,18 +57,29 @@ def pyflowline_generate_basin_template_configuration_json_file(sFilename_basins_
 
     return aBasin_out
 
-def pyflowline_generate_template_configuration_json_file(sFilename_json, sPath_data,\
-          iFlag_standalone_in=None,\
-        iFlag_use_mesh_dem_in=None,\
-        iFlag_use_shapefile_extent_in=None,\
-        iCase_index_in=None, \
-         dResolution_degree_in = None,\
-         dResolution_meter_in = None,\
-         sDate_in = None,\
-         sMesh_type_in = None, \
-             sModel_in = None,\
-                     sWorkspace_output_in = None):
-   
+
+def pyflowline_generate_template_configuration_json_file(sFilename_json, \
+    sWorkspace_input, sWorkspace_output, iFlag_standalone_in=None, \
+        iFlag_use_mesh_dem_in=None, iFlag_use_shapefile_extent_in=None,  iCase_index_in=None,    dResolution_degree_in = None, dResolution_meter_in = None,   sDate_in = None,  sMesh_type_in = None,    sModel_in = None):
+    """generate pyflowline config template file
+
+    Args:
+        sFilename_json (str): _description_
+        sWorkspace_input (str): _description_
+        iFlag_standalone_in (int, optional): _description_. Defaults to None.
+        iFlag_use_mesh_dem_in (int, optional): _description_. Defaults to None.
+        iFlag_use_shapefile_extent_in (int, optional): _description_. Defaults to None.
+        iCase_index_in (int, optional): _description_. Defaults to None.
+        dResolution_degree_in (float, optional): _description_. Defaults to None.
+        dResolution_meter_in (float, optional): _description_. Defaults to None.
+        sDate_in (str, optional): _description_. Defaults to None.
+        sMesh_type_in (str, optional): _description_. Defaults to None.
+        sModel_in (str, optional): _description_. Defaults to None.
+        sWorkspace_output_in (str, optional): _description_. Defaults to None.
+
+    Returns:
+        _type_: _description_
+    """
     if os.path.exists(sFilename_json):         
         os.remove(sFilename_json)
 
@@ -91,8 +114,7 @@ def pyflowline_generate_template_configuration_json_file(sFilename_json, sPath_d
         sDate = '20220202'
         pass
     
-    sPath_data_input = str(Path(sPath_data)  /  'input')
-
+    
     nBasin = 1
 
  
@@ -114,11 +136,12 @@ def pyflowline_generate_template_configuration_json_file(sFilename_json, sPath_d
     aConfig['dLatitude_bot'] = -90
     aConfig['dLatitude_top'] = 90
     aConfig['sFilename_model_configuration']  = sFilename_json 
-    aConfig['sWorkspace_data'] = sPath_data
+
+    aConfig['sWorkspace_input'] = sWorkspace_input
     
-    aConfig['sWorkspace_project'] = 'pyflowline' #not needed
+    aConfig['sWorkspace_output'] = sWorkspace_output
     
-    aConfig['sWorkspace_output'] = str(Path(sPath_data)  /  'output')
+    #aConfig['sWorkspace_project'] = 'pyflowline' #not needed
     
     aConfig['sRegion'] = 'susquehanna'
     aConfig['sModel'] = 'pyflowline'
@@ -128,15 +151,14 @@ def pyflowline_generate_template_configuration_json_file(sFilename_json, sPath_d
     aConfig['sJob'] = 'pyflowline'
     aConfig['sDate']= sDate
 
-    aConfig['sFilename_mesh_netcdf'] = str(Path(sPath_data_input)  /  'lnd_cull_mesh.nc')
-    
+    #full path
+    aConfig['sFilename_mesh_netcdf'] = str(Path(sWorkspace_input)  /  'lnd_cull_mesh.nc')
+    aConfig['sFilename_spatial_reference'] =  str(Path(sWorkspace_input)  /  'boundary_proj.shp')
+   
+    #relative path
     aConfig['flowline_info'] = 'flowline_info.json'
     aConfig['sFilename_mesh_info'] = 'mesh_info.json'
-    aConfig['sFilename_elevation'] = 'elevation.json'
-   
-    aConfig['sFilename_spatial_reference'] =  str(Path(sPath_data_input)  /  'boundary_proj.shp')
-   
-    
+    aConfig['sFilename_elevation'] = 'elevation.json' 
 
     oModel = flowlinecase(aConfig)
 
@@ -145,8 +167,9 @@ def pyflowline_generate_template_configuration_json_file(sFilename_json, sPath_d
     sFilename =  Path(sFilename_json).stem + '_basins.json'
     sFilename_basins_json = os.path.join(sDirname, sFilename)
 
-    aBasin = pyflowline_generate_basin_template_configuration_json_file(sFilename_basins_json, nBasin, \
-        oModel.sWorkspace_output, sPath_data_input)
+    
+
+    aBasin = pyflowline_generate_basin_template_configuration_json_file(sFilename_basins_json, nBasin, sWorkspace_input,  sWorkspace_output)
 
     oModel.aBasin = aBasin
     oModel.sFilename_basins = sFilename_basins_json
